package iotcloud;

import java.nio.ByteBuffer;

/**
 * This Entry records the abort sent by a given machine.
 * @author Ali Younis <ayounis@uci.edu>
 * @version 1.0
 */


class Abort extends Entry {
	private long seqnumtrans;
	private long machineid;

	Abort(Slot slot, long _seqnumtrans, long _machineid) {
		super(slot);
		seqnumtrans=_seqnumtrans;
		machineid=_machineid;
	}

	long getMachineID() {
		return machineid;
	}

	long getTransSequenceNumber() {
		return seqnumtrans;
	}

	static Entry decode(Slot slot, ByteBuffer bb) {
		long seqnumtrans=bb.getLong();
		long machineid=bb.getLong();
		return new Abort(slot, seqnumtrans, machineid);
	}

	void encode(ByteBuffer bb) {
		bb.put(Entry.TypeAbort);
		bb.putLong(seqnumtrans);
		bb.putLong(machineid);
	}

	int getSize() {
		return (2 * Long.BYTES) + Byte.BYTES;
	}

	byte getType() {
		return Entry.TypeAbort;
	}

	Entry getCopy(Slot s) {
		return new Abort(s, seqnumtrans, machineid);
	}
}